function mctable5(fitted,Setup,Targets,name)
    Setup.Size = [.111; .199; .69]; % override initial sizes
    Setup.CBR = [.020; .035; .035]; % override initial CBR
    Setup.PostCDR = [.0075; .0075; .010]; % override post-UMT CDR
    Setup.PreCDR = Setup.PostCDR;
    Setup.CBRMin = [0; 0; 0];
    Setup.Tau = [0; 0; 0]; % override birth rate path  
    
    comp = 50; % number of years to look ahead for results
    i = 1;
    
    % Write headers to file
    filename = sprintf('../Drafts/table_jv_%s_5.txt',name);
    f = fopen(filename,'w');
    
    fprintf(f,'Initial values (in 2005): & %9.1f & 1.0 & %9.1f & 1.0 & n/a \\tabularnewline[+0.05cm] \\cline{1-6} \n', ...
        100*Targets{1,'Value'},100*Targets{2,'Value'});
    fprintf(f,'\\noalign{\\medskip} After 50 years (2055): \\tabularnewline[+0.20cm] \n');
    
    % Call model
    R = mcfix(comp+1,fitted,Setup);
    v = R{comp,'Welfare'}; % get welfare comp year
    fprintf(f,'%9.0f. Baseline economy & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.175cm] \n', ...
        i, ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'},1);
    i = i + 1;

    fprintf(f,'\\multicolumn{6}{c}{\\textit{Productivity changes:}} \\tabularnewline[+0.175cm] \n');

    % Higher productivity growth in rural areas
    Alt = Setup;
    Alt{'Rural','Growth'} = Setup{'Rural','Growth'} + .01;
    R = mcfix(comp+1,fitted,Alt);
    fprintf(f,'%9.0f. Higher rural growth ($G_r = %9.3f$) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        Alt{'Rural','Growth'}, ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;
        
    % Higher productivity growth in informal areas
    Alt = Setup;
    Alt{'Informal','Growth'} = Setup{'Informal','Growth'} + .01;
    R = mcfix(comp+1,fitted,Alt);
    fprintf(f,'%9.0f. Higher informal growth ($G_l = %9.3f$) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        Alt{'Informal','Growth'}, ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;

    % Higher productivity growth in formal areas
    Alt = Setup;
    Alt{'Formal','Growth'} = Setup{'Formal','Growth'} + 0.01;
    R = mcfix(comp+1,fitted,Alt);
    fprintf(f,'%9.0f. Higher formal growth ($G_f = %9.2f$) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        Alt{'Formal','Growth'}, ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;
        
    % Higher productivity growth in formal areas
    Alt = Setup;
    Alt{'Formal','Growth'} = Setup{'Formal','Growth'} + 0.03;
    R = mcfix(comp+1,fitted,Alt);
    fprintf(f,'%9.0f. Higher formal growth ($G_f = %9.2f$) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        Alt{'Formal','Growth'}, ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;
        
    % Higher productivity growth in formal areas
    Alt = Setup;
    Alt{'Formal','Growth'} = Setup{'Formal','Growth'} + 0.05;
    R = mcfix(comp+1,fitted,Alt);
    fprintf(f,'%9.0f. Higher formal growth ($G_f = %9.2f$) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        Alt{'Formal','Growth'}, ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;
    
    fprintf(f,'\\multicolumn{6}{c}{\\textit{Congestion costs:}} \\tabularnewline[+0.175cm] \n');
    
    % Lower formal congestion
    altparam = fitted;
    altparam(1) = Setup{'Rural','Epsilon'}; % set formal = rural elasticity
    R = mcfix(comp+1,altparam,Setup);
    fprintf(f,'%9.0f. Lower formal congestion ($\\epsilon_f = \\epsilon_r = %9.2f $) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        altparam(1), ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;
    
    % Lower formal congestion = informal
    altparam = fitted;
    altparam(1) = altparam(2); % set formal = informal elasticity
    R = mcfix(comp+1,altparam,Setup);
    fprintf(f,'%9.0f. Lower formal congestion ($\\epsilon_f = \\epsilon_l = %9.2f $) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        altparam(1), ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;

    % Lower formal congestion
    altparam = fitted;
    altparam(1) = 0.33*fitted(1); % set formal = 67% lower
    R = mcfix(comp+1,altparam,Setup);
    fprintf(f,'%9.0f. Lower formal congestion ($\\epsilon_f = %9.2f $) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        altparam(1), ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;

    % Lower formal congestion
    altparam = fitted;
    altparam(1) = 0.9; % equal to lowest individual formal elasticity
    R = mcfix(comp+1,altparam,Setup);
    fprintf(f,'%9.0f. Lower formal congestion ($\\epsilon_f = %9.2f $) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        altparam(1), ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;
    
    % Higher informal congestion
    altparam = fitted;
    altparam(2) = altparam(1); % set informal = formal elasticity
    R = mcfix(comp+1,altparam,Setup);
    fprintf(f,'%9.0f. Higher informal congestion ($\\epsilon_f = \\epsilon_l = %9.2f $) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        altparam(2), ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;

    fprintf(f,'\\multicolumn{6}{c}{\\textit{Migration costs:}} \\tabularnewline[+0.175cm] \n');

    % Rural to urban migration restrictions
    Alt = Setup;
    Alt.Lambda = [0; 0; -.01];  
    R = mcfix(comp+1,fitted,Alt);
    fprintf(f,'%9.0f. Rural-to-urban mig restriction ($\\lambda_{cr} = %9.2f $) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        Alt{'Rural','Lambda'}, ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;

    % Urban to rural migration restrictions
    Alt = Setup;
    Alt.Lambda = [0; 0; .01];  
    R = mcfix(comp+1,fitted,Alt);
    fprintf(f,'%9.0f. Urban-to-rural mig restriction ($\\lambda_{cr} = %9.2f $) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        Alt{'Rural','Lambda'}, ... 
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;
 

    fprintf(f,'\\multicolumn{6}{c}{\\textit{Population growth changes:}} \\tabularnewline[+0.175cm] \n');
    
    % Zero population growth
    Alt = Setup;
    Alt.CBR = Alt.PostCDR;
    Alt.CBRMin = Alt.PostCDR;
    R = mcfix(comp+1,fitted,Alt);
    fprintf(f,'%9.0f. Zero population growth (CDR = CBR) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;

    % Family planning
    Alt = Setup;
    Alt.CBR = [0.020; 0.020; 0.020];
    Alt.CBRMin = Alt.CBR;
    R = mcfix(comp+1,fitted,Alt);
    fprintf(f,'%9.0f. Family planning (CBR = 20) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;

    % Informal Family planning
    Alt = Setup;
    Alt.CBR = [0.020; 0.020; 0.035];
    Alt.CBRMin = Alt.CBR;
    R = mcfix(comp+1,fitted,Alt);
    fprintf(f,'%9.0f. Informal Family planning (Informal CBR = 20) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;
        
    % Rural Family planning
    Alt = Setup;
    Alt.CBR = [0.020; 0.035; 0.020];
    Alt.CBRMin = Alt.CBR;
    R = mcfix(comp+1,fitted,Alt);
    fprintf(f,'%9.0f. Rural Family planning (Rur CBR = 20) & %9.1f & %9.1f & %9.1f & %9.1f & %9.2f \\tabularnewline[+0.01in] \n', ...
        i, ...
        100*R{comp,'UrbPerc'}, ...
        R{comp,'RelUrbSize'}, ...
        100*R{comp,'InfUrbPerc'}, ...
        R{comp,'RelInfSize'}, R{comp,'Welfare'}/v);
    i = i + 1;
    
    fclose(f);    
end
