function mctable3(fitted,Setup,time,Targets,name)
    
    filename = sprintf('../Drafts/table_jv_%s_3.txt',name);
    f = fopen(filename,'w');
    
    i = 1;
    
    % Print observed data
    fprintf(f,'%9.0f. \\emph{Observed data:} & %9.1f & %9.1f & 1.0 & %9.1f & n/a & %9.1f & 1.0 & %9.1f & n/a \\tabularnewline[+0.015in] \\cline{1-10} \n', ...
        i, ...
        100*(Setup{'Formal','Size'} + Setup{'Informal','Size'})/sum(Setup{:,'Size'}), ...
        100*Targets{1,'Value'}, ...
        Setup{'Formal','Relative'}, ... % This 'formal' field stores the urban relative size
        100*Targets{2,'Value'}, ...
        Setup{'Informal','Relative'} ...
    );
    
    fprintf(f,'\\noalign{\\smallskip} \\multicolumn{10}{l}{\\emph{Calibrated model:}} \\tabularnewline[+0.015in] \n');
    
    % Call model to replicate UMT with fitted parameters
    R = mcfix(time,fitted,Setup);
    aggeps = R{time,'AggEps'};
    basev = R{time,'Welfare'};
    fprintf(f,'\\noalign{\\smallskip} %9.0f. With UMT & %9.1f & %9.1f & 1.0 & %9.1f & %9.1f & %9.1f & 1.0 & %9.1f & 1.00 \\tabularnewline[+0.015in] \n', ...
        i, ...
        100*(Setup{'Formal','Size'} + Setup{'Informal','Size'})/sum(Setup{:,'Size'}), ...
        100*R{time,'UrbPerc'},R{time,'RelUrbSize'}, ...
        100*Setup{'Informal','Size'}/(Setup{'Formal','Size'} + Setup{'Informal','Size'}), ...
        100*R{time,'InfUrbPerc'},R{time,'RelInfSize'});
    i = i + 1;

 % Call model w/o UMT with fitted parameter
    Alt = Setup; 
    Alt.PostCDR = Alt.PreCDR; % alt has no difference in pre/post CDR
    R = mcfix(time,fitted,Alt);
    fprintf(f,'\\noalign{\\smallskip} %9.0f. Without UMT & %9.1f & %9.1f & 1.0 & %9.1f & %9.1f & %9.1f & 1.0 & %9.1f & %9.2f \\tabularnewline[+0.015in] \n', ...
        i, ...
        100*(Setup{'Formal','Size'} + Setup{'Informal','Size'})/sum(Setup{:,'Size'}), ...
        100*R{time,'UrbPerc'},R{time,'RelUrbSize'}, ...
        100*Setup{'Informal','Size'}/(Setup{'Formal','Size'} + Setup{'Informal','Size'}), ...
        100*R{time,'InfUrbPerc'},R{time,'RelInfSize'}, ...
        R{time,'Welfare'}/basev);
    i = i + 1;    
    
    % Replicate UMT but with CDR preference at zero
    Alt = Setup;
    Alt.UMT = [0; 3; 0];
    R = mcfix(time,fitted,Alt);
    fprintf(f,'\\noalign{\\smallskip} %9.0f. With UMT, $\\beta = 0$ & %9.1f & %9.1f & 1.0 & %9.1f & %9.1f & %9.1f & 1.0 & %9.1f & %9.2f \\tabularnewline[+0.015in] \n', ...
        i, ...
        100*(Setup{'Formal','Size'} + Setup{'Informal','Size'})/sum(Setup{:,'Size'}), ...
        100*R{time,'UrbPerc'},R{time,'RelUrbSize'}, ...
        100*Setup{'Informal','Size'}/(Setup{'Formal','Size'} + Setup{'Informal','Size'}), ...
        100*R{time,'InfUrbPerc'},R{time,'RelInfSize'}, ...
        R{time,'Welfare'}/basev);
    i = i + 1;
    
    % Replicate UMT with equal epsilons
    Alt = Setup;
    Alt.Epsilon = [aggeps; aggeps; aggeps];
    altfitted = fitted;
    altfitted(1) = aggeps;
    altfitted(2) = aggeps;
    R = mcfix(time,altfitted,Alt);
    fprintf(f,'\\noalign{\\smallskip} %9.0f. With UMT, $\\epsilon_i = \\overline{\\epsilon} = %9.2f $ & %9.1f & %9.1f & 1.0 & %9.1f & %9.1f & %9.1f & 1.0 & %9.1f & %9.2f \\tabularnewline[+0.015in] \n', ...
        i, ...
        aggeps, ...
        100*(Setup{'Formal','Size'} + Setup{'Informal','Size'})/sum(Setup{:,'Size'}), ...
        100*R{time,'UrbPerc'},R{time,'RelUrbSize'}, ...
        100*Setup{'Informal','Size'}/(Setup{'Formal','Size'} + Setup{'Informal','Size'}), ...
        100*R{time,'InfUrbPerc'},R{time,'RelInfSize'}, ...
        R{time,'Welfare'}/basev); 
    i = i + 1;

    % Call model w/o UMT and w/o fertility response with fitted parameters
    Alt = Setup; 
    Alt.PostCDR = Alt.PreCDR; % alt has no difference in pre/post CDR
    Alt.Tau = [0; 0; 0]; % no change in CBR over time
    R = mcfix(time,fitted,Alt);
    fprintf(f,'\\noalign{\\smallskip} %9.0f. W/o UMT, constant fertility & %9.1f & %9.1f & 1.0 & %9.1f & %9.1f & %9.1f & 1.0 & %9.1f & %9.2f \\tabularnewline[+0.015in] \n', ...
        i, ...
        100*(Setup{'Formal','Size'} + Setup{'Informal','Size'})/sum(Setup{:,'Size'}), ...
        100*R{time,'UrbPerc'},R{time,'RelUrbSize'}, ...
        100*Setup{'Informal','Size'}/(Setup{'Formal','Size'} + Setup{'Informal','Size'}), ...
        100*R{time,'InfUrbPerc'},R{time,'RelInfSize'}, ...
        R{time,'Welfare'}/basev);
    i = i + 1;
     
    % Call model w/o UMT and w/ endogenous fertility response with fitted parameters
    Alt = Setup; 
    Alt.PostCDR = Alt.PreCDR; % alt has no difference in pre/post CDR
    Alt.Fertility = [-.3; -.3; 1]; % use endogenous fert responses
    Alt.Tau = [0; 0; 0]; % no change in CBR over time
    R = mcfix(time,fitted,Alt);
    fprintf(f,'\\noalign{\\smallskip} %9.0f. W/o UMT, endogenous fertility & %9.1f & %9.1f & 1.0 & %9.1f & %9.1f & %9.1f & 1.0 & %9.1f & %9.2f \\tabularnewline[+0.015in] \n', ...
        i, ...
        100*(Setup{'Formal','Size'} + Setup{'Informal','Size'})/sum(Setup{:,'Size'}), ...
        100*R{time,'UrbPerc'},R{time,'RelUrbSize'}, ...
        100*Setup{'Informal','Size'}/(Setup{'Formal','Size'} + Setup{'Informal','Size'}), ...
        100*R{time,'InfUrbPerc'},R{time,'RelInfSize'}, ...
        R{time,'Welfare'}/basev);
    i = i + 1;
       
    fclose(f);    
end
