cd "C:\Users\Remi\Desktop\Replication Files Jedwab & Vollrath 2018\Figure 2"

*********************************************
* CITY LIVING STANDARDS AND POPULATION 2010 *
*********************************************

* As a measure of city living standards circa 2010, we use available data on city productivity in 1998-2012.

*** CITY DEVELOPMENT INDEX 1998 (cdi98) ***

* We first use the city development index of 1998.
* Source: United Nations Habitat. 1998. Global Urban Indicators Database. Nairobi, Kenya: UN-Habitat.
* Data is available for 161 cities. 
clear
import excel "cdi_100_cities.xls", sheet("summary") firstrow
count
* 161
replace city = "Manila" if city == "Mandaluyong"
ren cdi cdi98
ren infra infra98
keep country city cdi98 infra98
sort city
save cdi98, replace

*** CITY PROSPERITY INDEX 2012 (cpi12) ***

* We then use the city prosperity index of 2012.
* Source: United Nations Habitat. 2012. State of the World's Cities Report 2012/2013: Prosperity of Cities. Nairobi, Kenya: UN-Habitat
* There are two versions, cpi4 and cpi5. cpi5 includes a measure of equity. cpi4 is thus more equivalent to the city development index of 1998. We thus use cpi4.
clear
import excel "cpi_cities.xls", sheet("Feuil1") firstrow clear
keep country city cpi4 infra
ren infra infra12
ren cpi4 cpi12
sort city
save cpi12, replace

*** WE MERGE THE TWO ***

use cpi12, clear
sort city
merge city using cdi98
tab _m
drop _m
sort city
replace cdi98 = cdi98/100
sum cdi98 cpi12, d
* 161 obs for cdi98: from 0.217 to 0.980
* 69 obs for cpi12: from 0.285 to 0.936
* For each measure, we use the maximal value to create an index from 0 to 1:
replace cdi98 = cdi98 / 0.98
replace cpi12 = cpi12 / 0.936
sum cdi98 cpi12, d
corr cdi98 cpi12
* We use cpi12 as the main measure and replace it by cdi98 when it is missing: 
gen cdi98cpi12 = cpi12
replace cdi98cpi12 = cdi98 if cpi12 == .
codebook cdi98cpi12
* It is now available for 204 observations.
save cdi98cpi12, replace

*** WE ADD DATA ON POPULATION 2010 ***

use jv2015_city, clear
keep country city p2010
sort city
save popdata, replace

* We merge the data set on living standards with the data on population from the World Urbanizartion Prospects.
use cdi98cpi12, clear
sort city
merge city using popdata
tab _m
* This is for the observations that were matched. 
keep if _m == 3
drop _m
keep city cdi98cpi12 p2010
save cdi98cpi12_match, replace

* The World Urbanization Prospects database only has data for cities above 300,000 at one point since 1950.
* For the other observations, we use data from Wikipedia, and then merge the two data sets.
clear
import excel "city_notmatch.xlsx", sheet("Sheet1") firstrow 
replace p2010 = p2010_wiki_000s if p2010 == .
keep city cdi98cpi12 p2010
append using cdi98cpi12_match
ren cdi98cpi12 welfare
ren p2010 pop
gsort- welfare
gen rank_welfare = _n
gsort- pop
gen rank_pop = _n
gen sample = "new"
save cdi98cpi12_match, replace
count
* 204

*************************************************
* CITY LIVING STANDARDS AND POPULATION PRE-1910 *
*************************************************

**** WELFARE RATIOS AND POPULATION ****

* We focus on cities above 100,000:
clear
import excel "welfare_ratios_all.xlsx", sheet("raw") firstrow
keep if city_size_000s >= 100 | (city == "Nairobi" & year == 1930)
drop if city_size == . |  welfare == .
gsort- welfare
gen rank_welfare = _n
gsort- city_size_000s
gen rank_pop = _n
keep city rank* city_size_000s year
ren city_size_000s pop
gen sample = "old"
save wr_100, replace 
count
* 119

******************************
* WE MERGE THE TWO DATABASES *
******************************

use cdi98cpi12_match, clear
* Since we have 118 observations pre-1910, we keep the top 118 observations in 2010.
keep if rank_pop <= 119
drop rank_welfare
gsort- welfare
gen rank_welfare = _n
append using wr_100
tab sample
sort city year
replace rank_welfare = -rank_welfare  
replace rank_pop = -rank_pop
keep sample city year rank_pop rank_welfare pop
label var city "City"
label var year "Year"
label var rank_pop "Rank in terms of population"
label var rank_welfare "Rank in terms of living standars"
label var sample "Sample: new if 2010, old if pre-1910"
label var pop "Population"
order sample city year rank* pop
save data_for_figure2, replace

*************
* FIGURE 2A *
*************

use data_for_figure2, clear
reg rank_welfare rank_pop [pw=pop] if sample == "new", robust
reg rank_welfare rank_pop [pw=pop] if sample == "old", robust
twoway (scatter rank_welfare rank_pop if sample == "new", mcolor(gs10) msize(medsmall) msymbol(circle)) (scatter rank_welfare rank_pop if sample == "old", mcolor(gs6) msize(medium) msymbol(smsquare_hollow))(lfit rank_welfare rank_pop [pw=pop] if sample == "new", lcolor(black) lwidth(thick) lpattern(dash))(lfit rank_welfare rank_pop [pw=pop] if sample == "old", lcolor(black) lwidth(thick) lpattern(solid)), ytitle(Rank by City Living Standard) ytitle(, size(medium) color(black) margin(small)) xtitle(Rank by City Size) xtitle(, size(medium) color(black) margin(small)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) graphregion(margin(small)) xlabel(-100(50)0) ylabel(-100(50)0) legend(order(1 "2010 (b = 0.31)" 2 "Pre-1910 (b = 0.60)" 3 "" 4 "") row(1))
* We create the figure manually and then save it and export it.
graph use "figure2a.gph" 
graph export figure2a.png, replace width(2620) height(1908)

*************
* FIGURE 2B *
*************

use data_for_figure2, clear
* The observations for which the year is missing is 2010.
replace year = 2010 if year == .
* We select a few cities for which we keep selected years. 
keep if city == "New York" | city == "Amsterdam" | city == "London" | city == "Delhi" | city == "Jakarta" | city == "Lagos" | city == "Nairobi"
drop if city == "Amsterdam" & (year != 1700 & year != 1900 & year != 2010)
drop if city == "Delhi" & (year != 1875 & year != 2010)
drop if city == "London" & (year != 1700 & year != 1900 & year != 2010)
drop if city == "Jakarta" & (year != 1900 & year != 2010)
gen cityyear = city + " " + string(year)
twoway (scatter rank_welfare rank_pop if sample == "new", mcolor(gs6) msize(medsmall) msymbol(circle) mlabel(cityyear) mlabsize(small) mlabcolor(black)) (scatter rank_welfare rank_pop if sample == "old", mcolor(black) msize(medium) msymbol(smsquare_hollow) mlabel(cityyear) mlabsize(small) mlabcolor(black)), ytitle(Rank by City Living Standard) ytitle(, size(medium) color(black) margin(small)) xtitle(Rank by City Size) xtitle(, size(medium) color(black) margin(small)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) graphregion(margin(small)) legend(off) xlabel(-100(50)0) ylabel(-100(50)0)
* We create the figure manually and then save it and export it.
graph use "figure2b.gph" 
graph export figure2b.png, replace width(2620) height(1908)


