cd "C:\Users\Remi\Desktop\Replication Files Jedwab & Vollrath 2018\Figure 5\Figure 5a 5b"

*********************
***FIGURES 5A & 5B***
*********************

*** Data on demography ***

* We first use our demographic data set to obtain the crude rates of natural increase for the urban areas, the rural areas and the whole country.
use demography, clear
* We keep the rates for the 1960s.
keep if sample == "1960s" 
gen ni_urban = birth_urban - death_urban
gen ni_rural = birth_rural - death_rural
gen ni_total = birth_total - death_total
label var ni_urban "Crude rate of natural increase of the urban areas"
label var ni_rural "Crude rate of natural increase of the rural areas"
label var ni_total "Crude rate of natural increase of the whole country"
keep country city ni_* 
sort city
save demography1960s2000s, replace

*** Population ***

* We add to the data set the population of each country in both 1950 and 2015.
clear
import excel "pop.xlsx", sheet("Sheet1") firstrow clear
drop if ccode >= 900
keep country pop1950 pop2015 ccode
sort country
foreach X of numlist 1950 2015 {
gen str12 pop`X'new = subinstr(pop`X'," ","",.)
drop pop`X'
destring pop`X'new, replace
ren pop`X'new totpop`X'
}
replace country = "Cote d'Ivoire" in 57
label var totpop1950 "Total population of the country in 1950"
label var totpop2015 "Total population of the country in 2015"
sort country
save pop, replace

*** Urbanization rate ***

* We add to the data set the urbanization rate of each country in both 1950 and 2015.
clear
import excel "urb.xlsx", sheet("Sheet1") firstrow clear
drop if ccode >= 900
keep country urb1950 urb2015 ccode
sort country
replace country = "Cote d'Ivoire" in 57
label var urb1950 "Urbanization rate of the country in 1950"
label var urb2015 "Urbanization rate of the country in 2015"
sort country
save urb, replace

*** We merge the demographic data set with the population and urbanization data sets ***

use demography1960s2000s, clear
* In order to merge the data, we change the name of some countries. 
replace country = "Burkina Faso" if country == "Burkina-Faso"
replace country = "China, Hong Kong SAR" if country == "Hong Kong"
replace country = "Iran (Islamic Republic of)" if country == "Iran"
replace country = "Cote d'Ivoire" if country == "Ivory Coast"
replace country = "Russian Federation" if country == "Russia"
replace country = "Republic of Korea" if country == "South Korea"
replace country = "Syrian Arab Republic" if country == "Syria"
replace country = "United Republic of Tanzania" if country == "Tanzania"
replace country = "United States of America" if country == "United States"
replace country = "Viet Nam" if country == "Vietnam"
* We merge with the population and urbanization data. 
sort country
merge country using pop
tab _m
drop if _m == 2
drop _m
sort country
merge country using urb
tab _m
drop if _m == 2
drop _m
* We create the urban and rural populations.
foreach X of numlist 1950 2015 {
gen upop`X' = totpop`X'/100*urb`X'
}
foreach X of numlist 1950 2015 {
gen rpop`X' = totpop`X'/100*(100-urb`X')
}
label var upop1950 "Urban population of the country in 1950"
label var upop2015 "Urban population of the country in 2015"
label var rpop1950 "Rural population of the country in 1950"
label var rpop2015 "Rural population of the country in 2015"
* We now create the urban and rural growth rates between 1950 and 2015.
gen gr5015_r = ((rpop2015/rpop1950)^(1/65)-1)*100
sum gr5015_r, d
* There are two countries for which it is -100%. It is because these countries are small countries with no countryside. We replace the value by a missing value.
tab country if gr5015_r == -100
replace gr5015_r = . if country == "China, Hong Kong SAR" | country == "Singapore" 
gen gr5015_u = ((upop2015/upop1950)^(1/65)-1)*100
label var gr5015_r "Annual growth rate of the rural population 1950-2015"
label var gr5015_u "Annual growth rate of the urban population 1950-2015"
desc

* We now create the figures

* Figure 5A *
reg gr5015_u ni_urban, robust
reg gr5015_r ni_rural, robust
twoway (lfit gr5015_r ni_rural, lcolor(gs6) lwidth(medthick) lpattern(dash))(scatter gr5015_r ni_rural, mcolor(gs14) msize(large) msymbol(triangle) mlcolor(gs8) mlwidth(medium))(lfit gr5015_u ni_urban, lcolor(black) lwidth(medthick) lpattern(dash))(scatter gr5015_u ni_urban, mcolor(gs14) msize(large) msymbol(circle) mlcolor(black) mlwidth(medium)), ytitle(Annual Growth Rate (%) in 1950-2015) ytitle(, margin(small)) xtitle(Crude Rate of Natural Increase (Per 1,000 People) in the 1960s) xtitle(, margin(small)) xlabel(10(10)30) legend(off) graphregion(margin(small) fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually modify the figure before exporting it.
graph use "figure5a.gph"
graph export figure5a.png, replace width(2620) height(1908)

* Figure 5B *
reg gr5015_u ni_total, robust
reg gr5015_r ni_total, robust
twoway (lfit gr5015_r ni_total, lcolor(gs6) lwidth(medthick) lpattern(dash))(scatter gr5015_r ni_total, mcolor(gs14) msize(medlarge) msymbol(diamond) mlcolor(gs8) mlwidth(medium))(lfit gr5015_u ni_urban, lcolor(black) lwidth(medthick) lpattern(dash))(scatter gr5015_u ni_urban, mcolor(gs14) msize(large) msymbol(circle) mlcolor(black) mlwidth(medium)), ytitle(Annual Growth Rate (%) in 1950-2015) ytitle(, margin(small)) xtitle(Crude Rate of Natural Increase (Per 1,000 People) in the 1960s) xtitle(, margin(small)) xlabel(10(10)30) ylabel(0(2)6) legend(off) graphregion(margin(small) fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually modify the figure before exporting it.
graph use "figure5b.gph"
graph export figure5b.png, replace width(2620) height(1908)

